package br.com.tito.kitca.common.entity;

import br.com.petrobras.snarf.common.entity.AbstractIdBean;
import java.io.Serializable;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.OneToMany;
import javax.persistence.Table;


@Entity
@Table(name = "EMPRESA", schema = "CA")
public class Empresa extends AbstractIdBean<Long> implements Serializable {

    
    private static final long serialVersionUID = 1L;
    public static final String PROPRIEDADE_ID = "id";
    public static final String PROPRIEDADE_NOME = "nome";
    public static final String PROPRIEDADE_DESCRICAO = "descricao";
    public static final String PROPRIEDADE_AMBIENTES = "ambientes";
    public static final String PROPRIEDADE_USUARIOS = "usuarios";
   
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Column(name="EMPR_SQ_EMPRESA", nullable=false)
    private Long id;

    @Column(name="EMPR_DS_NOME", nullable=false)
    private String nome;

    @Column(name="EMPR_DS_DESCRICAO", nullable=false)
    private String descricao;

    @OneToMany(mappedBy = Ambiente.PROPRIEDADE_EMPRESA, fetch=FetchType.LAZY)
    private Set<Ambiente> ambientes;

    @OneToMany(mappedBy = Usuario.PROPRIEDADE_EMPRESA, fetch=FetchType.LAZY)
    private Set<Usuario> usuarios;
    
    // <editor-fold defaultstate="collapsed" desc="Getters">

    public Long getId() {
        return id;
    }

    public String getNome() {
        return nome;
    }

    public String getDescricao() {
        return descricao;
    }

    public List<Ambiente> getAmbientes() {
        return setToList(ambientes);
    }

    public List<Usuario> getUsuarios() {
        return setToList(usuarios);
    }

    // </editor-fold>

    // <editor-fold defaultstate="collapsed" desc="Setters">

    public void setNome(String nome) {
        Object old = this.nome;
        this.nome = nome;
        firePropertyChange(PROPRIEDADE_NOME, old, this.nome);
    }

    public void setDescricao(String descricao) {
        Object old = this.descricao;
        this.descricao = descricao;
        firePropertyChange(PROPRIEDADE_DESCRICAO, old, this.descricao);
    }


    // </editor-fold>

    // <editor-fold defaultstate="collapsed" desc="Metodos adicionar e remover">

    public void adicionarAmbiente(Ambiente a) {
        if (a==null)
            return;
        if (ambientes==null)
            ambientes = new HashSet();
        ambientes.add(a);
        firePropertyChange(PROPRIEDADE_AMBIENTES, null, getAmbientes());
    }

    public void removerAmbiente(Ambiente a) {
        if (a==null)
            return;
        if (ambientes==null)
            ambientes = new HashSet();
        ambientes.remove(a);
        firePropertyChange(PROPRIEDADE_AMBIENTES, null, getAmbientes());
    }

    public void adicionarUsuario(Usuario u) {
        if (u==null)
            return;
        if (usuarios==null)
            usuarios = new HashSet();
        usuarios.add(u);
        firePropertyChange(PROPRIEDADE_USUARIOS, null, getUsuarios());
    }

    public void removerUsuario(Usuario u) {
        if (u==null)
            return;
        if (usuarios==null)
            usuarios = new HashSet();
        usuarios.remove(u);
        firePropertyChange(PROPRIEDADE_USUARIOS, null, getUsuarios());
    }


    // </editor-fold>

    @Override
    public String toString() {
        return nome;
    }

}
